@@ -55,6 +55,7 @@ pub trait SpecifierStackExt {
     fn contains(&self, t: &'static str) -> bool;
     fn is_multiconnect(&self) -> bool;
     fn is_stream_oriented(&self) -> bool;
+    fn autotoreconn_misuse(&self)  -> bool;
     fn insert_line_class_in_proper_place(&mut self, x: Rc<dyn SpecifierClass>);
 }
 impl SpecifierStackExt for SpecifierStack {
@@ -93,6 +94,20 @@ impl SpecifierStackExt for SpecifierStack {
         }
         self.addrtype.cls.get_name() == t
     }
+    fn autotoreconn_misuse(&self)  -> bool {
+        let mut autoreconnect_found = false;
+        for overlay in &self.overlays {
+            if overlay.cls.get_name() == "AutoReconnectClass" {
+                autoreconnect_found = true;
+            }
+            if overlay.cls.get_name() == "BroadcastReuserClass" || overlay.cls.get_name() == "ReuserClass" {
+                if autoreconnect_found {
+                    return true;
+                }
+            }
+        }
+        false
+    }
     fn is_multiconnect(&self) -> bool {
         use super::ClassMulticonnectStatus::*;
         match self.addrtype.cls.multiconnect_status() {
@@ -474,6 +489,9 @@ impl WebsocatConfiguration2 {
         if self.opts.pkcs12_der.is_some() &&  !self.contains_class("TlsAcceptClass") {
             Err("--pkcs12-der makes no sense without an TLS connections acceptor")?;
         }
+        if self.opts.pkcs12_der.is_none() &&  self.contains_class("TlsAcceptClass") {
+            Err("You need to specify server key and certificate using the --pkcs12-der option to use the TLS connections acceptor")?;
+        }
         if self.opts.client_pkcs12_der.is_some() && !self.contains_class("WsClientSecureClass") && !self.contains_class("TlsConnectClass") {
             Err("--client-pkcs12-der makes no sense without wss:// or ssl: connectors")?;
         }
@@ -586,7 +604,7 @@ impl WebsocatConfiguration2 {
     fn l_crypto(&mut self, _on_warning: &OnWarning) -> Result<()> {
         #[cfg(feature="crypto_peer")]
         if self.opts.crypto_key.is_some() {
-            if !self.contains_class("CryptoCLass") {
+            if !self.contains_class("CryptoClass") {
                 _on_warning("--crypto-key option is meaningless without a `crypto:` overlay");
             }
         }
@@ -630,13 +648,59 @@ impl WebsocatConfiguration2 {
         #[cfg(not(feature="compression"))]
         {
             if cn > 0 || un > 0 {
-                return Err("Compression support is not selected during Websocat compiltion")?;
+                return Err("Compression support is not selected during Websocat compilation")?;
             }
         }
         Ok(())
     }
+    #[cfg(feature="native_plugins")]
+    fn l_plugins(&mut self, _on_warning: &OnWarning) -> Result<()> {
+        if self.contains_class("NativeTransformAClass") && self.opts.native_transform_a.is_none() {
+            return Err("--native-plugin-a must be specified to use `native_plugin_transform_a:`")?;
+        }
+        if self.contains_class("NativeTransformBClass") && self.opts.native_transform_b.is_none() {
+            return Err("--native-plugin-b must be specified to use `native_plugin_transform_b:`")?;
+        }
+        if self.contains_class("NativeTransformCClass") && self.opts.native_transform_c.is_none() {
+            return Err("--native-plugin-c must be specified to use `native_plugin_transform_c:`")?;
+        }
+        if self.contains_class("NativeTransformDClass") && self.opts.native_transform_d.is_none() {
+            return Err("--native-plugin-d must be specified to use `native_plugin_transform_d:`")?;
+        }
+        Ok(())
+    }
+    #[cfg(not(feature="native_plugins"))]
+    fn l_plugins(&mut self, _on_warning: &OnWarning) -> Result<()> {
+        Ok(())
+    }
 
+    #[cfg(feature="wasm_plugins")]
+    fn l_wasm(&mut self, _on_warning: &OnWarning) -> Result<()> {
+        if self.contains_class("WasmTransformAClass") && self.opts.wasm_transform_a.is_none() {
+            return Err("--wasm-plugin-a must be specified to use `wasm_plugin_transform_a:`")?;
+        }
+        if self.contains_class("WasmTransformBClass") && self.opts.wasm_transform_b.is_none() {
+            return Err("--wasm-plugin-b must be specified to use `wasm_plugin_transform_b:`")?;
+        }
+        if self.contains_class("WasmTransformCClass") && self.opts.wasm_transform_c.is_none() {
+            return Err("--wasm-plugin-c must be specified to use `wasm_plugin_transform_c:`")?;
+        }
+        if self.contains_class("WasmTransformDClass") && self.opts.wasm_transform_d.is_none() {
+            return Err("--wasm-plugin-d must be specified to use `wasm_plugin_transform_d:`")?;
+        }
+        Ok(())
+    }
+    #[cfg(not(feature="wasm_plugins"))]
+    fn l_wasm(&mut self, _on_warning: &OnWarning) -> Result<()> {
+        Ok(())
+    }
 
+    fn l_autoreconn_reuse(&mut self, _on_warning: &OnWarning) -> Result<()> {
+        if self.s1.autotoreconn_misuse() || self.s2.autotoreconn_misuse() {
+            _on_warning("Warning: `autoreconnect:reuse:` is a bad overlay combination. Maybe you want `reuse:autoreconnect:");
+        }
+        Ok(())
+    }
 
     pub fn lint_and_fixup(&mut self, on_warning: OnWarning) -> Result<()> {
         let multiconnect = !self.opts.oneshot && self.s1.is_multiconnect();
@@ -662,6 +726,9 @@ impl WebsocatConfiguration2 {
         self.l_crypto(&on_warning)?;
         self.l_sizelimits(&on_warning)?;
         self.l_compress(&on_warning)?;
+        self.l_plugins(&on_warning)?;
+        self.l_wasm(&on_warning)?;
+        self.l_autoreconn_reuse(&on_warning)?;
 
         // TODO: UDP connect oneshot mode
         // TODO: tests for the linter
