@@ -133,7 +133,7 @@ impl CompressionMethod {
             return x;
         }
 
-        error!("Compression support is not selected during Websocat compiltion");
+        error!("Compression support is not selected during Websocat compilation");
         vec![]
     }
 
@@ -143,7 +143,7 @@ impl CompressionMethod {
             return x;
         }
 
-        error!("Compression support is not selected during Websocat compiltion");
+        error!("Compression support is not selected during Websocat compilation");
         vec![]
     }
 }
@@ -161,6 +161,7 @@ pub struct WsReadWrapper<T: WsStream + 'static> {
     pub text_base64: bool,
     pub creation_time: ::std::time::Instant, // for measuring ping RTTs
     pub print_rtts: bool,
+    pub inhibit_pongs: Option<usize>,
     pub uncompress : CompressionMethod,
 }
 
@@ -219,8 +220,15 @@ impl<T: WsStream + 'static> Read for WsReadWrapper<T> {
                     info!("incoming None");
                     abort_and_broken_pipe!()
                 }
+                Ready(Some(OwnedMessage::Ping(_x))) if self.inhibit_pongs == Some(0) => {
+                    info!("Received and ignored WebSocket ping");
+                    continue;
+                }
                 Ready(Some(OwnedMessage::Ping(x))) => {
                     info!("Received WebSocket ping");
+                    if let Some(ref mut ip) = self.inhibit_pongs {
+                        *ip = ip.wrapping_sub(1);
+                    }
                     let om = OwnedMessage::Pong(x);
                     let mut sink = self.pingreply.borrow_mut();
                     let mut proceed = false;
@@ -480,6 +488,7 @@ pub struct WsPinger<T: WsStream + 'static> {
     t: ::tokio_timer::Interval,
     origin: ::std::time::Instant,
     aborter: ::futures::unsync::oneshot::Receiver<()>,
+    max_sent_pings: Option<usize>,
 }
 
 impl<T: WsStream + 'static> WsPinger<T> {
@@ -488,6 +497,7 @@ impl<T: WsStream + 'static> WsPinger<T> {
         interval: ::std::time::Duration,
         origin: ::std::time::Instant,
         aborter: ::futures::unsync::oneshot::Receiver<()>,
+        max_sent_pings: Option<usize>,
     ) -> Self {
         WsPinger {
             st: WsPingerState::WaitingForTimer,
@@ -495,6 +505,7 @@ impl<T: WsStream + 'static> WsPinger<T> {
             si: sink,
             origin,
             aborter,
+            max_sent_pings,
         }
     }
 }
@@ -522,6 +533,15 @@ impl<T: WsStream + 'static> ::futures::Future for WsPinger<T> {
                     Ok(Async::Ready(None)) => warn!("tokio-timer's interval stream ended?"),
                     Ok(Async::NotReady) => return Ok(Async::NotReady),
                     Ok(Async::Ready(Some(_instant))) => {
+                        if let Some(ref mut maxnum) = self.max_sent_pings {
+                            if *maxnum > 0 {
+                                *maxnum -= 1;
+                            } else {
+                                info!("Not sending WebSocket pings anymore");
+                                self.st = WaitingForTimer;
+                                continue;
+                            }
+                        }
                         self.st = StartSend;
                         info!("Sending WebSocket ping");
                         continue;
@@ -583,7 +603,7 @@ pub fn finish_building_ws_peer<S>(opts: &super::Options, duplex: Duplex<S>, clos
         let (tx, rx) = ::futures::unsync::oneshot::channel();
 
         let intv = ::std::time::Duration::from_secs(d);
-        let pinger = super::ws_peer::WsPinger::new(mpsink.clone(), intv,now, rx);
+        let pinger = super::ws_peer::WsPinger::new(mpsink.clone(), intv,now, rx, opts.max_sent_pings);
         ::tokio_current_thread::spawn(pinger);
         Some(tx)
     } else {
@@ -638,6 +658,7 @@ pub fn finish_building_ws_peer<S>(opts: &super::Options, duplex: Duplex<S>, clos
         text_base64: opts.ws_text_base64,
         creation_time: now,
         print_rtts: opts.print_ping_rtts,
+        inhibit_pongs: opts.inhibit_pongs,
         uncompress,
     };
     let ws_sin = WsWriteWrapper{
